Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(415)

Unified Diff: chrome/browser/chromeos/input_method/input_method_manager_impl.h

Issue 232333002: ozone: Rename XKeyboard to KeyboardController & use fake under ozone (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/input_method/input_method_manager_impl.h
diff --git a/chrome/browser/chromeos/input_method/input_method_manager_impl.h b/chrome/browser/chromeos/input_method/input_method_manager_impl.h
index 23ec79c9ed4e4739c52f29d5ad65ae91d2ffd0d7..71e230cc137933ec6762251513a5b7d9bc07c0b9 100644
--- a/chrome/browser/chromeos/input_method/input_method_manager_impl.h
+++ b/chrome/browser/chromeos/input_method/input_method_manager_impl.h
@@ -23,7 +23,7 @@ class ComponentExtensionIMEManagerDelegate;
class InputMethodEngine;
namespace input_method {
class InputMethodDelegate;
-class XKeyboard;
+class KeyboardController;
// The implementation of InputMethodManager.
class InputMethodManagerImpl : public InputMethodManager,
@@ -34,7 +34,7 @@ class InputMethodManagerImpl : public InputMethodManager,
explicit InputMethodManagerImpl(scoped_ptr<InputMethodDelegate> delegate);
virtual ~InputMethodManagerImpl();
// Attach CandidateWindowController, and XKeyboard objects to the
// InputMethodManagerImpl object. You don't have to call this
// function if you attach them yourself (e.g. in unit tests) using
// the protected setters.
@@ -84,7 +84,7 @@ class InputMethodManagerImpl : public InputMethodManager,
virtual bool IsISOLevel5ShiftUsedByCurrentInputMethod() const OVERRIDE;
virtual bool IsAltGrUsedByCurrentInputMethod() const OVERRIDE;
- virtual XKeyboard* GetXKeyboard() OVERRIDE;
+ virtual KeyboardController* GetKeyboardController() OVERRIDE;
virtual InputMethodUtil* GetInputMethodUtil() OVERRIDE;
virtual ComponentExtensionIMEManager*
GetComponentExtensionIMEManager() OVERRIDE;
@@ -97,7 +97,7 @@ class InputMethodManagerImpl : public InputMethodManager,
void SetCandidateWindowControllerForTesting(
CandidateWindowController* candidate_window_controller);
// Sets |xkeyboard_|.
- void SetXKeyboardForTesting(XKeyboard* xkeyboard);
+ void SetKeyboardControllerForTesting(KeyboardController* xkeyboard);
// Initialize |component_extension_manager_|.
void InitializeComponentExtensionForTesting(
scoped_ptr<ComponentExtensionIMEManagerDelegate> delegate);
@@ -204,7 +204,7 @@ class InputMethodManagerImpl : public InputMethodManager,
// An object for switching XKB layouts and keyboard status like caps lock and
// auto-repeat interval.
- scoped_ptr<XKeyboard> xkeyboard_;
+ scoped_ptr<KeyboardController> xkeyboard_;
std::string pending_input_method_;

Powered by Google App Engine
@@ -34,7 +34,7 @@ class InputMethodManagerImpl : public InputMethodManager,
explicit InputMethodManagerImpl(scoped_ptr<InputMethodDelegate> delegate);
virtual ~InputMethodManagerImpl();
- // Attach CandidateWindowController, and XKeyboard objects to the
+ // Attach CandidateWindowController, and KeyboardController objects to the
// InputMethodManagerImpl object. You don't have to call this
// function if you attach them yourself (e.g. in unit tests) using
This is Rietveld 408576698